if __name__ == "__main__":
    from devcloud_sagemaker.sm_client import print_hello_world
    from devcloud_sagemaker.sm_client import create_training_job 

    # print_hello_world()

